@@ -20,7 +20,7 @@ from github import Github
 from commands import auth
 from commands import allrepo
 from commands import selectrepo
-from commands import webhook
+# from commands import webhook
 
 
 
@@ -43,7 +43,7 @@ buildpan.add_command(auth.auth)
 buildpan.add_command(allrepo.allrepo)
 buildpan.add_command(selectrepo.selectrepo)
 # buildpan.add_command(reset.reset)
-buildpan.add_command(webhook.create_webhook)
+# buildpan.add_command(webhook.create_webhook)
 if __name__ == '__main__':
     main()
     
